Support
=======

If you are stuck with a problem using MQT Bench or have questions, please do get in touch at our `Issues <https://github.com/cda-tum/mqt-bench/issues>`_ or `Discussions <https://github.com/cda-tum/mqt-bench/discussions>`_. We'd love to help.

You can save time by following this procedure when reporting a problem:

- Do try to solve the problem on your own first. Make sure to consult the `Documentation <https://mqt.readthedocs.io/projects/bench>`_.
- Search through past `Issues <https://github.com/cda-tum/mqt-bench/issues>`_ to see if someone else already had the same problem.
- Before filing a bug report, try to create a minimal working example (MWE) that reproduces the problem. It's much easier to identify the cause for the problem if a handful of lines suffice to show that something isn't working.

You can also always reach us at `quantum.cda@xcit.tum.de <mailto:quantum.cda@xcit.tum.de>`_.
